summaryrefslogtreecommitdiff
path: root/src/osal/osal_freertos.h
diff options
context:
space:
mode:
authorhathach <[email protected]>2025-05-19 22:51:40 +0700
committerhathach <[email protected]>2025-05-19 22:51:40 +0700
commitbb1d348eb3908543f7bc80fc462d91bba62edace (patch)
tree73268b6ccd7a7d70ff4498698ce05e9b72516c14 /src/osal/osal_freertos.h
parentbffe5d97cc2f4f5a9ba8b4f09d30be97ce70a3de (diff)
implement osal critical for none/freertos/pico-sdk
Diffstat (limited to 'src/osal/osal_freertos.h')
-rw-r--r--src/osal/osal_freertos.h30
1 files changed, 21 insertions, 9 deletions
diff --git a/src/osal/osal_freertos.h b/src/osal/osal_freertos.h
index ba998bfa1..5d6534709 100644
--- a/src/osal/osal_freertos.h
+++ b/src/osal/osal_freertos.h
@@ -102,38 +102,50 @@ TU_ATTR_ALWAYS_INLINE static inline void osal_task_delay(uint32_t msec) {
//--------------------------------------------------------------------+
// Critical API
//--------------------------------------------------------------------+
+#define OSAL_CRITIAL_DEF(_name, _int_set) \
+ osal_critical_t _name
+
#if TUSB_MCU_VENDOR_ESPRESSIF
// Espressif critical take spinlock as argument
typedef portMUX_TYPE osal_critical_t;
TU_ATTR_ALWAYS_INLINE static inline void osal_critical_init(osal_critical_t *ctx) {
spinlock_initialize(ctx);
}
-TU_ATTR_ALWAYS_INLINE static inline void osal_critical_enter(osal_critical_t *ctx) {
+TU_ATTR_ALWAYS_INLINE static inline void osal_critical_enter(osal_critical_t *ctx, bool in_isr) {
+ (void) in_isr;
portENTER_CRITICAL(ctx);
}
-TU_ATTR_ALWAYS_INLINE static inline void osal_critical_exit(osal_critical_t *ctx) {
+TU_ATTR_ALWAYS_INLINE static inline void osal_critical_exit(osal_critical_t *ctx, bool in_isr) {
+ (void) in_isr;
portEXIT_CRITICAL(ctx);
}
#else
-typedef uint8_t osal_critical_t; // not used
+typedef UBaseType_t osal_critical_t;
TU_ATTR_ALWAYS_INLINE static inline void osal_critical_init(osal_critical_t *ctx) {
(void) ctx;
}
-TU_ATTR_ALWAYS_INLINE static inline void osal_critical_enter(osal_critical_t *ctx) {
- (void) ctx;
- portENTER_CRITICAL();
+TU_ATTR_ALWAYS_INLINE static inline void osal_critical_enter(osal_critical_t *ctx, bool in_isr) {
+ if (in_isr) {
+ *ctx = taskENTER_CRITICAL_FROM_ISR();
+ } else {
+ taskENTER_CRITICAL();
+ }
}
-TU_ATTR_ALWAYS_INLINE static inline void osal_critical_exit(osal_critical_t *ctx) {
+TU_ATTR_ALWAYS_INLINE static inline void osal_critical_exit(osal_critical_t *ctx, bool in_isr) {
(void) ctx;
- portEXIT_CRITICAL();
+ if (in_isr) {
+ taskEXIT_CRITICAL_FROM_ISR(*ctx);
+ } else {
+ taskEXIT_CRITICAL();
+ }
}
#endif
@@ -102,38 +102,50 @@ TU_ATTR_ALWAYS_INLINE static inline void osal_task_delay(uint32_t msec) {
#if TUSB_MCU_VENDOR_ESPRESSIF
-// Espressif critical take spinlock as argument
+// Espressif critical take spinlock as argument and does not use in_isr
typedef portMUX_TYPE osal_critical_t;
TU_ATTR_ALWAYS_INLINE static inline void osal_critical_init(osal_critical_t *ctx) {